var searchData=
[
  ['j',['j',['../structsquare.html#a37256b73c566788e11f09488bb09edd1',1,'square::j()'],['../structoctave__value__ref.html#a2a0b2a3136acfe707cc5e8cc5c05e9d2',1,'octave_value_ref::j()']]],
  ['java_5fexception',['java_exception',['../structSWIG__JavaExceptions__t.html#a38dd5a9090f6d6c09f43d85536bc3154',1,'SWIG_JavaExceptions_t']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fbase_5f1cont_5f1get',['Java_plplot_core_plplotjavacJNI_BASE_1CONT_1get',['../plplotjavacJAVA__wrap_8c.html#afd2ddbf8e08b6024d1a7f18f4f49fd47',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fdelete_5f1plgraphicsin',['Java_plplot_core_plplotjavacJNI_delete_1PLGraphicsIn',['../plplotjavacJAVA__wrap_8c.html#a6d31233bffd93e9608cbdf5d5d18b63f',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fdraw_5f1linex_5f1get',['Java_plplot_core_plplotjavacJNI_DRAW_1LINEX_1get',['../plplotjavacJAVA__wrap_8c.html#a036881733178a89df208ab426345766c',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fdraw_5f1linexy_5f1get',['Java_plplot_core_plplotjavacJNI_DRAW_1LINEXY_1get',['../plplotjavacJAVA__wrap_8c.html#aaa0307d000d7c8068b76277212437828',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fdraw_5f1liney_5f1get',['Java_plplot_core_plplotjavacJNI_DRAW_1LINEY_1get',['../plplotjavacJAVA__wrap_8c.html#a30b477b1108fb25888b60ed006a71335',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fdraw_5f1sides_5f1get',['Java_plplot_core_plplotjavacJNI_DRAW_1SIDES_1get',['../plplotjavacJAVA__wrap_8c.html#a761024c1ec53637d621acc812d4557cb',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5ffaceted_5f1get',['Java_plplot_core_plplotjavacJNI_FACETED_1get',['../plplotjavacJAVA__wrap_8c.html#ac2c1218b1bede44f30cac8210b4684fd',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fgrid_5f1csa_5f1get',['Java_plplot_core_plplotjavacJNI_GRID_1CSA_1get',['../plplotjavacJAVA__wrap_8c.html#aa78c3b09564447ec4b84c202d87672ff',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fgrid_5f1dtli_5f1get',['Java_plplot_core_plplotjavacJNI_GRID_1DTLI_1get',['../plplotjavacJAVA__wrap_8c.html#a776edd94f51ac7e98f9f47c589ef5de7',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fgrid_5f1nnaidw_5f1get',['Java_plplot_core_plplotjavacJNI_GRID_1NNAIDW_1get',['../plplotjavacJAVA__wrap_8c.html#a50cd98400f9c2747a0d663837c900405',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fgrid_5f1nni_5f1get',['Java_plplot_core_plplotjavacJNI_GRID_1NNI_1get',['../plplotjavacJAVA__wrap_8c.html#a37593af570d3e50f8157f49cb3a66a6d',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fgrid_5f1nnidw_5f1get',['Java_plplot_core_plplotjavacJNI_GRID_1NNIDW_1get',['../plplotjavacJAVA__wrap_8c.html#acaa9d75fcfe5a2a0a4056795fbd93082',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fgrid_5f1nnli_5f1get',['Java_plplot_core_plplotjavacJNI_GRID_1NNLI_1get',['../plplotjavacJAVA__wrap_8c.html#a98a2ccb9e9d30bec17df4c577ca956e2',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fjplfltarray_5f1get',['Java_plplot_core_plplotjavacJNI_jPLFLTArray_1get',['../plplotjavacJAVA__wrap_8c.html#affd2b1463f7b2ae2b966b980b61fa8a6',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fjplfltbracket2_5f1get',['Java_plplot_core_plplotjavacJNI_jPLFLTbracket2_1get',['../plplotjavacJAVA__wrap_8c.html#a3aa1caff2b32a3d0e33197a5347f8f54',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fjplfltbracket_5f1get',['Java_plplot_core_plplotjavacJNI_jPLFLTbracket_1get',['../plplotjavacJAVA__wrap_8c.html#a9675abbf8afb55c265d13404d214d924',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fmag_5f1color_5f1get',['Java_plplot_core_plplotjavacJNI_MAG_1COLOR_1get',['../plplotjavacJAVA__wrap_8c.html#a737bcf0a575578354d98842910eb3242',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fmesh_5f1get',['Java_plplot_core_plplotjavacJNI_MESH_1get',['../plplotjavacJAVA__wrap_8c.html#a83750177a62d70b86cc21afb6756faf2',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fnew_5f1plgraphicsin',['Java_plplot_core_plplotjavacJNI_new_1PLGraphicsIn',['../plplotjavacJAVA__wrap_8c.html#ae89fdce01f8720e8ef49ecf0a506ce72',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fonew2b_5f1get',['Java_plplot_core_plplotjavacJNI_ONEW2B_1get',['../plplotjavacJAVA__wrap_8c.html#a0ae2560cc3017c0d8f75d1d0e8e0f138',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fonew2d_5f1get',['Java_plplot_core_plplotjavacJNI_ONEW2D_1get',['../plplotjavacJAVA__wrap_8c.html#a34adbbe38d084293b813d35b0235b1ec',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fpl_5f1bin_5f1centred_5f1get',['Java_plplot_core_plplotjavacJNI_PL_1BIN_1CENTRED_1get',['../plplotjavacJAVA__wrap_8c.html#a7dd073f725e1a27b05204e1e2991e37d',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fpl_5f1bin_5f1default_5f1get',['Java_plplot_core_plplotjavacJNI_PL_1BIN_1DEFAULT_1get',['../plplotjavacJAVA__wrap_8c.html#a9853884f73c9222fad25307669064911',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fpl_5f1bin_5f1noempty_5f1get',['Java_plplot_core_plplotjavacJNI_PL_1BIN_1NOEMPTY_1get',['../plplotjavacJAVA__wrap_8c.html#add8da351ab4a02a79e7ba12efd6e52e6',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fpl_5f1bin_5f1noexpand_5f1get',['Java_plplot_core_plplotjavacJNI_PL_1BIN_1NOEXPAND_1get',['../plplotjavacJAVA__wrap_8c.html#a2635413c2cc88b28f3f0fec962e17c58',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fpl_5f1colorbar_5f1background_5f1get',['Java_plplot_core_plplotjavacJNI_PL_1COLORBAR_1BACKGROUND_1get',['../plplotjavacJAVA__wrap_8c.html#a20782d3f31708883d169cc9230f349d0',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fpl_5f1colorbar_5f1bounding_5f1box_5f1get',['Java_plplot_core_plplotjavacJNI_PL_1COLORBAR_1BOUNDING_1BOX_1get',['../plplotjavacJAVA__wrap_8c.html#add507119c5d2abe47c4b24d6d4137eaa',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fpl_5f1colorbar_5f1cap_5f1high_5f1get',['Java_plplot_core_plplotjavacJNI_PL_1COLORBAR_1CAP_1HIGH_1get',['../plplotjavacJAVA__wrap_8c.html#a05a9738172c9bb49ebbb5ac75e161417',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fpl_5f1colorbar_5f1cap_5f1low_5f1get',['Java_plplot_core_plplotjavacJNI_PL_1COLORBAR_1CAP_1LOW_1get',['../plplotjavacJAVA__wrap_8c.html#a9beea084b683236057f9f3b9d4977a1a',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fpl_5f1colorbar_5f1cap_5f1none_5f1get',['Java_plplot_core_plplotjavacJNI_PL_1COLORBAR_1CAP_1NONE_1get',['../plplotjavacJAVA__wrap_8c.html#a2d5d9d7e4a6687ae16afe3213ef0a64d',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fpl_5f1colorbar_5f1gradient_5f1get',['Java_plplot_core_plplotjavacJNI_PL_1COLORBAR_1GRADIENT_1get',['../plplotjavacJAVA__wrap_8c.html#aa1a8d8ef3d8840aa8b3efb55f5c4af47',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fpl_5f1colorbar_5f1image_5f1get',['Java_plplot_core_plplotjavacJNI_PL_1COLORBAR_1IMAGE_1get',['../plplotjavacJAVA__wrap_8c.html#a411d801b1dfab92a5f0324f5597ad37c',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fpl_5f1colorbar_5f1label_5f1bottom_5f1get',['Java_plplot_core_plplotjavacJNI_PL_1COLORBAR_1LABEL_1BOTTOM_1get',['../plplotjavacJAVA__wrap_8c.html#ae5e3de1928a5598bcc240f5edd8b4f0d',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fpl_5f1colorbar_5f1label_5f1left_5f1get',['Java_plplot_core_plplotjavacJNI_PL_1COLORBAR_1LABEL_1LEFT_1get',['../plplotjavacJAVA__wrap_8c.html#a052d361be27098a495b4422d841c220e',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fpl_5f1colorbar_5f1label_5f1right_5f1get',['Java_plplot_core_plplotjavacJNI_PL_1COLORBAR_1LABEL_1RIGHT_1get',['../plplotjavacJAVA__wrap_8c.html#ae612df216935b8e87a921fed11a08aba',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fpl_5f1colorbar_5f1label_5f1top_5f1get',['Java_plplot_core_plplotjavacJNI_PL_1COLORBAR_1LABEL_1TOP_1get',['../plplotjavacJAVA__wrap_8c.html#a070d10da7e707efb40b29d62f74017dd',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fpl_5f1colorbar_5f1orient_5f1bottom_5f1get',['Java_plplot_core_plplotjavacJNI_PL_1COLORBAR_1ORIENT_1BOTTOM_1get',['../plplotjavacJAVA__wrap_8c.html#a8d26b37f864b9ad3cf9e43de19b2bfc8',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fpl_5f1colorbar_5f1orient_5f1left_5f1get',['Java_plplot_core_plplotjavacJNI_PL_1COLORBAR_1ORIENT_1LEFT_1get',['../plplotjavacJAVA__wrap_8c.html#a1e1000857fd8322004370a57c0440f23',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fpl_5f1colorbar_5f1orient_5f1right_5f1get',['Java_plplot_core_plplotjavacJNI_PL_1COLORBAR_1ORIENT_1RIGHT_1get',['../plplotjavacJAVA__wrap_8c.html#afac4ab74ed11f948ee22f1d0bd97da70',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fpl_5f1colorbar_5f1orient_5f1top_5f1get',['Java_plplot_core_plplotjavacJNI_PL_1COLORBAR_1ORIENT_1TOP_1get',['../plplotjavacJAVA__wrap_8c.html#afed6a752b6faa48a6513ef3a9c8b9edd',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fpl_5f1colorbar_5f1shade_5f1get',['Java_plplot_core_plplotjavacJNI_PL_1COLORBAR_1SHADE_1get',['../plplotjavacJAVA__wrap_8c.html#a944b054fe218bbd16b138c81ade6ad6c',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fpl_5f1colorbar_5f1shade_5f1label_5f1get',['Java_plplot_core_plplotjavacJNI_PL_1COLORBAR_1SHADE_1LABEL_1get',['../plplotjavacJAVA__wrap_8c.html#a75139d6479bc828496dc5beeac48da3e',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fpl_5f1drawmode_5f1default_5f1get',['Java_plplot_core_plplotjavacJNI_PL_1DRAWMODE_1DEFAULT_1get',['../plplotjavacJAVA__wrap_8c.html#ade8f1a15516b405fd04548ce075d4a82',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fpl_5f1drawmode_5f1replace_5f1get',['Java_plplot_core_plplotjavacJNI_PL_1DRAWMODE_1REPLACE_1get',['../plplotjavacJAVA__wrap_8c.html#a351b1e60e4f3413410f0b1c23a7ae945',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fpl_5f1drawmode_5f1unknown_5f1get',['Java_plplot_core_plplotjavacJNI_PL_1DRAWMODE_1UNKNOWN_1get',['../plplotjavacJAVA__wrap_8c.html#a970dbcaa0855f4db69985e232d6ca393',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fpl_5f1drawmode_5f1xor_5f1get',['Java_plplot_core_plplotjavacJNI_PL_1DRAWMODE_1XOR_1get',['../plplotjavacJAVA__wrap_8c.html#a41d152f24a239a21e51d659706b2891c',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fpl_5f1fci_5f1bold_5f1get',['Java_plplot_core_plplotjavacJNI_PL_1FCI_1BOLD_1get',['../plplotjavacJAVA__wrap_8c.html#a38a0320b78ddfd449fc2dc5236389997',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fpl_5f1fci_5f1family_5f1get',['Java_plplot_core_plplotjavacJNI_PL_1FCI_1FAMILY_1get',['../plplotjavacJAVA__wrap_8c.html#ad4393fc1039a3d3eed1573da386b6342',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fpl_5f1fci_5f1hexdigit_5f1mask_5f1get',['Java_plplot_core_plplotjavacJNI_PL_1FCI_1HEXDIGIT_1MASK_1get',['../plplotjavacJAVA__wrap_8c.html#ac84ae12da638faaaa137488283eb5812',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fpl_5f1fci_5f1hexpower_5f1impossible_5f1get',['Java_plplot_core_plplotjavacJNI_PL_1FCI_1HEXPOWER_1IMPOSSIBLE_1get',['../plplotjavacJAVA__wrap_8c.html#a6a97a2a40dd2329be63d14e737fe4bff',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fpl_5f1fci_5f1hexpower_5f1mask_5f1get',['Java_plplot_core_plplotjavacJNI_PL_1FCI_1HEXPOWER_1MASK_1get',['../plplotjavacJAVA__wrap_8c.html#a241000bbf618287a063e88479b7a4bc5',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fpl_5f1fci_5f1impossible_5f1get',['Java_plplot_core_plplotjavacJNI_PL_1FCI_1IMPOSSIBLE_1get',['../plplotjavacJAVA__wrap_8c.html#a3483508daf7731e835e0a5c88683e4aa',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fpl_5f1fci_5f1italic_5f1get',['Java_plplot_core_plplotjavacJNI_PL_1FCI_1ITALIC_1get',['../plplotjavacJAVA__wrap_8c.html#a2f587f5e8378f8370c5d739ee2936f53',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fpl_5f1fci_5f1mark_5f1get',['Java_plplot_core_plplotjavacJNI_PL_1FCI_1MARK_1get',['../plplotjavacJAVA__wrap_8c.html#abcc92cb2604de6b38ed017dd238480ea',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fpl_5f1fci_5f1medium_5f1get',['Java_plplot_core_plplotjavacJNI_PL_1FCI_1MEDIUM_1get',['../plplotjavacJAVA__wrap_8c.html#a0a38e15d150bc8b4d8389170ae3047f2',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fpl_5f1fci_5f1mono_5f1get',['Java_plplot_core_plplotjavacJNI_PL_1FCI_1MONO_1get',['../plplotjavacJAVA__wrap_8c.html#ac4780713da398896a22e915d4580e542',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fpl_5f1fci_5f1oblique_5f1get',['Java_plplot_core_plplotjavacJNI_PL_1FCI_1OBLIQUE_1get',['../plplotjavacJAVA__wrap_8c.html#a1388c78781ac131d4126c6226a8e4d1b',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fpl_5f1fci_5f1sans_5f1get',['Java_plplot_core_plplotjavacJNI_PL_1FCI_1SANS_1get',['../plplotjavacJAVA__wrap_8c.html#aff1f8e0bf4f9dfda0384b368552df4db',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fpl_5f1fci_5f1script_5f1get',['Java_plplot_core_plplotjavacJNI_PL_1FCI_1SCRIPT_1get',['../plplotjavacJAVA__wrap_8c.html#ab38d60b2ed607556f2ed0d95d6b63711',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fpl_5f1fci_5f1serif_5f1get',['Java_plplot_core_plplotjavacJNI_PL_1FCI_1SERIF_1get',['../plplotjavacJAVA__wrap_8c.html#afa18ddecf7c5456daabecacbfba9c454',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fpl_5f1fci_5f1style_5f1get',['Java_plplot_core_plplotjavacJNI_PL_1FCI_1STYLE_1get',['../plplotjavacJAVA__wrap_8c.html#a0842260268c7170e859e43f8fa6dc052',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fpl_5f1fci_5f1symbol_5f1get',['Java_plplot_core_plplotjavacJNI_PL_1FCI_1SYMBOL_1get',['../plplotjavacJAVA__wrap_8c.html#aba47a1b581ea76adee8b7dbb27b14d15',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fpl_5f1fci_5f1upright_5f1get',['Java_plplot_core_plplotjavacJNI_PL_1FCI_1UPRIGHT_1get',['../plplotjavacJAVA__wrap_8c.html#aa29731a334d70335af525e503468e673',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fpl_5f1fci_5f1weight_5f1get',['Java_plplot_core_plplotjavacJNI_PL_1FCI_1WEIGHT_1get',['../plplotjavacJAVA__wrap_8c.html#a221e14583ec0d31f02493a50aa60d63d',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fpl_5f1hist_5f1default_5f1get',['Java_plplot_core_plplotjavacJNI_PL_1HIST_1DEFAULT_1get',['../plplotjavacJAVA__wrap_8c.html#a3c681cb1d780525265d6d0cde86a075f',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fpl_5f1hist_5f1ignore_5f1outliers_5f1get',['Java_plplot_core_plplotjavacJNI_PL_1HIST_1IGNORE_1OUTLIERS_1get',['../plplotjavacJAVA__wrap_8c.html#abcfab41cdc185157dc177fc71063c221',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fpl_5f1hist_5f1noempty_5f1get',['Java_plplot_core_plplotjavacJNI_PL_1HIST_1NOEMPTY_1get',['../plplotjavacJAVA__wrap_8c.html#aaa03c6ce6363d0762892b92d69547442',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fpl_5f1hist_5f1noexpand_5f1get',['Java_plplot_core_plplotjavacJNI_PL_1HIST_1NOEXPAND_1get',['../plplotjavacJAVA__wrap_8c.html#ae19693853e138f3578c779652d3147d5',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fpl_5f1hist_5f1noscaling_5f1get',['Java_plplot_core_plplotjavacJNI_PL_1HIST_1NOSCALING_1get',['../plplotjavacJAVA__wrap_8c.html#a0372382a67f3b7bffe39c4cb01e81ba6',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fpl_5f1legend_5f1background_5f1get',['Java_plplot_core_plplotjavacJNI_PL_1LEGEND_1BACKGROUND_1get',['../plplotjavacJAVA__wrap_8c.html#a18d7257da6bf689394245b8201615c3d',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fpl_5f1legend_5f1bounding_5f1box_5f1get',['Java_plplot_core_plplotjavacJNI_PL_1LEGEND_1BOUNDING_1BOX_1get',['../plplotjavacJAVA__wrap_8c.html#aa3ff79210804f4efb0d411a58e0d8d00',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fpl_5f1legend_5f1color_5f1box_5f1get',['Java_plplot_core_plplotjavacJNI_PL_1LEGEND_1COLOR_1BOX_1get',['../plplotjavacJAVA__wrap_8c.html#a9ad9272e81f6641d9301705de9390c56',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fpl_5f1legend_5f1line_5f1get',['Java_plplot_core_plplotjavacJNI_PL_1LEGEND_1LINE_1get',['../plplotjavacJAVA__wrap_8c.html#a358f2b2af730dec8a770b87abbc3367c',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fpl_5f1legend_5f1none_5f1get',['Java_plplot_core_plplotjavacJNI_PL_1LEGEND_1NONE_1get',['../plplotjavacJAVA__wrap_8c.html#a5c386c2cc48cedd3e2cfc616082b76ea',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fpl_5f1legend_5f1row_5f1major_5f1get',['Java_plplot_core_plplotjavacJNI_PL_1LEGEND_1ROW_1MAJOR_1get',['../plplotjavacJAVA__wrap_8c.html#a5fe839b754bdd7984a0d38207d052dcb',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fpl_5f1legend_5f1symbol_5f1get',['Java_plplot_core_plplotjavacJNI_PL_1LEGEND_1SYMBOL_1get',['../plplotjavacJAVA__wrap_8c.html#a091fd139747699e3a42e20442576560c',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fpl_5f1legend_5f1text_5f1left_5f1get',['Java_plplot_core_plplotjavacJNI_PL_1LEGEND_1TEXT_1LEFT_1get',['../plplotjavacJAVA__wrap_8c.html#a34187c2222f1a9950d20b7e72ca18a9f',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fpl_5f1maxkey_5f1get',['Java_plplot_core_plplotjavacJNI_PL_1MAXKEY_1get',['../plplotjavacJAVA__wrap_8c.html#a97eb1ed5da8025e1c8952aae1bae21fb',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fpl_5f1maxwindows_5f1get',['Java_plplot_core_plplotjavacJNI_PL_1MAXWINDOWS_1get',['../plplotjavacJAVA__wrap_8c.html#af1ae559551db9bc44f62dea426c9180b',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fpl_5f1notset_5f1get',['Java_plplot_core_plplotjavacJNI_PL_1NOTSET_1get',['../plplotjavacJAVA__wrap_8c.html#a7a300c0c873403fd5dede34f27f9bdde',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fpl_5f1opt_5f1arg_5f1get',['Java_plplot_core_plplotjavacJNI_PL_1OPT_1ARG_1get',['../plplotjavacJAVA__wrap_8c.html#aedb3c8a1bd640a459d628ffe72e7044c',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fpl_5f1opt_5f1bool_5f1get',['Java_plplot_core_plplotjavacJNI_PL_1OPT_1BOOL_1get',['../plplotjavacJAVA__wrap_8c.html#a9693cb83c6603e923ea10da51a5b1805',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fpl_5f1opt_5f1disabled_5f1get',['Java_plplot_core_plplotjavacJNI_PL_1OPT_1DISABLED_1get',['../plplotjavacJAVA__wrap_8c.html#ad46e4e018e243315ce863473a7690ed8',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fpl_5f1opt_5f1enabled_5f1get',['Java_plplot_core_plplotjavacJNI_PL_1OPT_1ENABLED_1get',['../plplotjavacJAVA__wrap_8c.html#a6cf5912d37178081b664d5d1bd06ec63',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fpl_5f1opt_5f1float_5f1get',['Java_plplot_core_plplotjavacJNI_PL_1OPT_1FLOAT_1get',['../plplotjavacJAVA__wrap_8c.html#a9fd111a1f93553d1ae9ec53eba1fc0ea',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fpl_5f1opt_5f1func_5f1get',['Java_plplot_core_plplotjavacJNI_PL_1OPT_1FUNC_1get',['../plplotjavacJAVA__wrap_8c.html#a6f266dd84f0ae9e928533211612990a7',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fpl_5f1opt_5f1int_5f1get',['Java_plplot_core_plplotjavacJNI_PL_1OPT_1INT_1get',['../plplotjavacJAVA__wrap_8c.html#ab74f5703049ab20e787329b4991a54a8',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fpl_5f1opt_5f1invisible_5f1get',['Java_plplot_core_plplotjavacJNI_PL_1OPT_1INVISIBLE_1get',['../plplotjavacJAVA__wrap_8c.html#a6df3c48c5832dd612a8a4c4781e297b3',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fpl_5f1opt_5f1nodelete_5f1get',['Java_plplot_core_plplotjavacJNI_PL_1OPT_1NODELETE_1get',['../plplotjavacJAVA__wrap_8c.html#adf90cf0393650e8f7f22bdcababf7b73',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fpl_5f1opt_5f1string_5f1get',['Java_plplot_core_plplotjavacJNI_PL_1OPT_1STRING_1get',['../plplotjavacJAVA__wrap_8c.html#a59931e30fd5d5f4a270211b0fdc8364d',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fpl_5f1parse_5f1full_5f1get',['Java_plplot_core_plplotjavacJNI_PL_1PARSE_1FULL_1get',['../plplotjavacJAVA__wrap_8c.html#a14e09fbfbf2f01134157094952702645',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fpl_5f1parse_5f1nodash_5f1get',['Java_plplot_core_plplotjavacJNI_PL_1PARSE_1NODASH_1get',['../plplotjavacJAVA__wrap_8c.html#a4bf92750abe28abcda1b04f086871fc6',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fpl_5f1parse_5f1nodelete_5f1get',['Java_plplot_core_plplotjavacJNI_PL_1PARSE_1NODELETE_1get',['../plplotjavacJAVA__wrap_8c.html#acce351cc37611326e8b071b0599dc956',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fpl_5f1parse_5f1noprogram_5f1get',['Java_plplot_core_plplotjavacJNI_PL_1PARSE_1NOPROGRAM_1get',['../plplotjavacJAVA__wrap_8c.html#a14926eccfb7a740df7a34d6a7a61b4c8',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fpl_5f1parse_5f1override_5f1get',['Java_plplot_core_plplotjavacJNI_PL_1PARSE_1OVERRIDE_1get',['../plplotjavacJAVA__wrap_8c.html#ad7fd5e2ce4ea33ddbead023aca643799',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fpl_5f1parse_5f1partial_5f1get',['Java_plplot_core_plplotjavacJNI_PL_1PARSE_1PARTIAL_1get',['../plplotjavacJAVA__wrap_8c.html#af8d9ed693436ecae0d73457325063547',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fpl_5f1parse_5f1quiet_5f1get',['Java_plplot_core_plplotjavacJNI_PL_1PARSE_1QUIET_1get',['../plplotjavacJAVA__wrap_8c.html#abbf362542af21a3868b62638ab561749',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fpl_5f1parse_5f1showall_5f1get',['Java_plplot_core_plplotjavacJNI_PL_1PARSE_1SHOWALL_1get',['../plplotjavacJAVA__wrap_8c.html#adaced2b51e0ae0481235f7e3f9523363',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fpl_5f1parse_5f1skip_5f1get',['Java_plplot_core_plplotjavacJNI_PL_1PARSE_1SKIP_1get',['../plplotjavacJAVA__wrap_8c.html#ae668b4026f1ab5f2adee1450e56d0c75',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fpl_5f1position_5f1bottom_5f1get',['Java_plplot_core_plplotjavacJNI_PL_1POSITION_1BOTTOM_1get',['../plplotjavacJAVA__wrap_8c.html#ae0b0019333f731d3028454d8cfe89940',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fpl_5f1position_5f1inside_5f1get',['Java_plplot_core_plplotjavacJNI_PL_1POSITION_1INSIDE_1get',['../plplotjavacJAVA__wrap_8c.html#a522724862caa78827b9da216c6f9e10b',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fpl_5f1position_5f1left_5f1get',['Java_plplot_core_plplotjavacJNI_PL_1POSITION_1LEFT_1get',['../plplotjavacJAVA__wrap_8c.html#ab0fd096eda0de90d693015d9a10b8dc8',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fpl_5f1position_5f1outside_5f1get',['Java_plplot_core_plplotjavacJNI_PL_1POSITION_1OUTSIDE_1get',['../plplotjavacJAVA__wrap_8c.html#acf927f118449e74fdcf3cb9ad612d6ae',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fpl_5f1position_5f1right_5f1get',['Java_plplot_core_plplotjavacJNI_PL_1POSITION_1RIGHT_1get',['../plplotjavacJAVA__wrap_8c.html#a319845b232b07573e61dad89bd2fa9f2',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fpl_5f1position_5f1subpage_5f1get',['Java_plplot_core_plplotjavacJNI_PL_1POSITION_1SUBPAGE_1get',['../plplotjavacJAVA__wrap_8c.html#a6495d6e8308c3fb785951b54df47fe9d',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fpl_5f1position_5f1top_5f1get',['Java_plplot_core_plplotjavacJNI_PL_1POSITION_1TOP_1get',['../plplotjavacJAVA__wrap_8c.html#a4d20ecb174524e95e24d2ac7fec07f58',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fpl_5f1position_5f1viewport_5f1get',['Java_plplot_core_plplotjavacJNI_PL_1POSITION_1VIEWPORT_1get',['../plplotjavacJAVA__wrap_8c.html#a85bb1a8a6d691573befafeb7b7907da8',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fpl_5f1setcontlabelformat',['Java_plplot_core_plplotjavacJNI_pl_1setcontlabelformat',['../plplotjavacJAVA__wrap_8c.html#aaa3ff836625a06ff5f4d0e1a50c60a0f',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fpl_5f1setcontlabelparam',['Java_plplot_core_plplotjavacJNI_pl_1setcontlabelparam',['../plplotjavacJAVA__wrap_8c.html#a419035fb96b135c1921422841403d694',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fpl_5f1x_5f1axis_5f1get',['Java_plplot_core_plplotjavacJNI_PL_1X_1AXIS_1get',['../plplotjavacJAVA__wrap_8c.html#a20290bc69c035a27b9e683ec3b749d51',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fpl_5f1y_5f1axis_5f1get',['Java_plplot_core_plplotjavacJNI_PL_1Y_1AXIS_1get',['../plplotjavacJAVA__wrap_8c.html#ac9c091339c5d8543c36fb73cdc198dd2',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fpl_5f1z_5f1axis_5f1get',['Java_plplot_core_plplotjavacJNI_PL_1Z_1AXIS_1get',['../plplotjavacJAVA__wrap_8c.html#a13ed92e7709474ce39ca76d9cee58235',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fpladv',['Java_plplot_core_plplotjavacJNI_pladv',['../plplotjavacJAVA__wrap_8c.html#adf39256170f5b4e9d9049c13e6451f88',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fplarc',['Java_plplot_core_plplotjavacJNI_plarc',['../plplotjavacJAVA__wrap_8c.html#ac62f76f8ef0857c5f434121302658a0e',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fplaxes',['Java_plplot_core_plplotjavacJNI_plaxes',['../plplotjavacJAVA__wrap_8c.html#ac395e440d62c4a9d7ced785fd6af07a4',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fplbin',['Java_plplot_core_plplotjavacJNI_plbin',['../plplotjavacJAVA__wrap_8c.html#a9c6da709c918873fccaadf9756f1bc9b',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fplbop',['Java_plplot_core_plplotjavacJNI_plbop',['../plplotjavacJAVA__wrap_8c.html#a489e4eb03919ced6325760c2b2a7ca02',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fplbox',['Java_plplot_core_plplotjavacJNI_plbox',['../plplotjavacJAVA__wrap_8c.html#a3f13db7359b31140286fa6c5084c1987',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fplbox3',['Java_plplot_core_plplotjavacJNI_plbox3',['../plplotjavacJAVA__wrap_8c.html#a25f017d4b7e3a709281e493bbb030493',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fplbtime',['Java_plplot_core_plplotjavacJNI_plbtime',['../plplotjavacJAVA__wrap_8c.html#af691e550a3b196389f958286405a51c6',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fplcalc_5f1world',['Java_plplot_core_plplotjavacJNI_plcalc_1world',['../plplotjavacJAVA__wrap_8c.html#ad88a88622ba80c48ab8e354e391d96a1',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fplclear',['Java_plplot_core_plplotjavacJNI_plclear',['../plplotjavacJAVA__wrap_8c.html#ae67af102361bf5aa0f42a9149798e4e6',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fplclearopts',['Java_plplot_core_plplotjavacJNI_plClearOpts',['../plplotjavacJAVA__wrap_8c.html#ad7b1c6ab374b8fef63896ebf2c334e45',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fplcol0',['Java_plplot_core_plplotjavacJNI_plcol0',['../plplotjavacJAVA__wrap_8c.html#a779c4c91f89ea234e821634f9c0aca1d',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fplcol1',['Java_plplot_core_plplotjavacJNI_plcol1',['../plplotjavacJAVA__wrap_8c.html#af307e56ace7f7d75777f3da8edaaf583',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fplcolorbar',['Java_plplot_core_plplotjavacJNI_plcolorbar',['../plplotjavacJAVA__wrap_8c.html#a6af9e6c64bff1d1a51b9567eebbf54aa',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fplconfigtime',['Java_plplot_core_plplotjavacJNI_plconfigtime',['../plplotjavacJAVA__wrap_8c.html#a328a848528a9e13e984ab24a797b968c',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fplcont',['Java_plplot_core_plplotjavacJNI_plcont',['../plplotjavacJAVA__wrap_8c.html#abb0eda489cf5018a09b24be5e6277d92',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fplcpstrm',['Java_plplot_core_plplotjavacJNI_plcpstrm',['../plplotjavacJAVA__wrap_8c.html#ac4cd8928e211f64ea4419e9948484059',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fplctime',['Java_plplot_core_plplotjavacJNI_plctime',['../plplotjavacJAVA__wrap_8c.html#a55824a7a93cbfc5b30674b153f95be54',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fplend',['Java_plplot_core_plplotjavacJNI_plend',['../plplotjavacJAVA__wrap_8c.html#a884c579b566361ab44d9c5870e0e8183',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fplend1',['Java_plplot_core_plplotjavacJNI_plend1',['../plplotjavacJAVA__wrap_8c.html#ac9f0e7b142fd903382938206819e1a44',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fplenv',['Java_plplot_core_plplotjavacJNI_plenv',['../plplotjavacJAVA__wrap_8c.html#a38502ec6d32a4d0e5265b08d0e8db841',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fplenv0',['Java_plplot_core_plplotjavacJNI_plenv0',['../plplotjavacJAVA__wrap_8c.html#a4891698fe77f54b849f614b35e2f85a1',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fpleop',['Java_plplot_core_plplotjavacJNI_pleop',['../plplotjavacJAVA__wrap_8c.html#ae35959b52a048fef60cae4f38e1ac0d7',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fplerrx',['Java_plplot_core_plplotjavacJNI_plerrx',['../plplotjavacJAVA__wrap_8c.html#a9840854dc9c0e852efcae638f6396495',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fplerry',['Java_plplot_core_plplotjavacJNI_plerry',['../plplotjavacJAVA__wrap_8c.html#a4a75fe85fea5b783878504a01888f771',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fplesc_5f1alloc_5f1ncol_5f1get',['Java_plplot_core_plplotjavacJNI_PLESC_1ALLOC_1NCOL_1get',['../plplotjavacJAVA__wrap_8c.html#af1e939044298915799807e37ec2fc48a',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fplesc_5f1append_5f1buffer_5f1get',['Java_plplot_core_plplotjavacJNI_PLESC_1APPEND_1BUFFER_1get',['../plplotjavacJAVA__wrap_8c.html#a764fe756de4100ad9be581aa560e6c58',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fplesc_5f1arc_5f1get',['Java_plplot_core_plplotjavacJNI_PLESC_1ARC_1get',['../plplotjavacJAVA__wrap_8c.html#aabed52349ef35ce2d701d5215a2ca1c8',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fplesc_5f1begin_5f1text_5f1get',['Java_plplot_core_plplotjavacJNI_PLESC_1BEGIN_1TEXT_1get',['../plplotjavacJAVA__wrap_8c.html#a96f244f98ebceb120fe9b143de29b1ee',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fplesc_5f1clear_5f1get',['Java_plplot_core_plplotjavacJNI_PLESC_1CLEAR_1get',['../plplotjavacJAVA__wrap_8c.html#af05798decef9c17f480fa391200538a0',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fplesc_5f1control_5f1char_5f1get',['Java_plplot_core_plplotjavacJNI_PLESC_1CONTROL_1CHAR_1get',['../plplotjavacJAVA__wrap_8c.html#ac33fcc2dc669c130faa9bd08635b2be4',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fplesc_5f1dash_5f1get',['Java_plplot_core_plplotjavacJNI_PLESC_1DASH_1get',['../plplotjavacJAVA__wrap_8c.html#af028379db20ac59111f87943ee113046',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fplesc_5f1dev2plcol_5f1get',['Java_plplot_core_plplotjavacJNI_PLESC_1DEV2PLCOL_1get',['../plplotjavacJAVA__wrap_8c.html#ad6213c6cd7caa7971f2850b6d43b8a80',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fplesc_5f1devinit_5f1get',['Java_plplot_core_plplotjavacJNI_PLESC_1DEVINIT_1get',['../plplotjavacJAVA__wrap_8c.html#a14ce21eaf9b38fe2cc601729c9d24ee7',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fplesc_5f1di_5f1get',['Java_plplot_core_plplotjavacJNI_PLESC_1DI_1get',['../plplotjavacJAVA__wrap_8c.html#a0104949947153ad24999158b306ee054',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fplesc_5f1doublebuffering_5f1disable_5f1get',['Java_plplot_core_plplotjavacJNI_PLESC_1DOUBLEBUFFERING_1DISABLE_1get',['../plplotjavacJAVA__wrap_8c.html#a71c5e5bd4bee8cd9d577bd59103f661d',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fplesc_5f1doublebuffering_5f1enable_5f1get',['Java_plplot_core_plplotjavacJNI_PLESC_1DOUBLEBUFFERING_1ENABLE_1get',['../plplotjavacJAVA__wrap_8c.html#aad6f806c835ede4ed3f4da3c29b4fd5b',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fplesc_5f1doublebuffering_5f1get',['Java_plplot_core_plplotjavacJNI_PLESC_1DOUBLEBUFFERING_1get',['../plplotjavacJAVA__wrap_8c.html#a5983d585865a4eeabed21ca4b5763aaa',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fplesc_5f1doublebuffering_5f1query_5f1get',['Java_plplot_core_plplotjavacJNI_PLESC_1DOUBLEBUFFERING_1QUERY_1get',['../plplotjavacJAVA__wrap_8c.html#a6e71aa773b971e27f3480c6b172bd97a',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fplesc_5f1eh_5f1get',['Java_plplot_core_plplotjavacJNI_PLESC_1EH_1get',['../plplotjavacJAVA__wrap_8c.html#a4c9baec3986233f966b6027a80e1cc12',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fplesc_5f1end_5f1rasterize_5f1get',['Java_plplot_core_plplotjavacJNI_PLESC_1END_1RASTERIZE_1get',['../plplotjavacJAVA__wrap_8c.html#a222a395c7627da07b30ba6f1aba031e3',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fplesc_5f1end_5f1text_5f1get',['Java_plplot_core_plplotjavacJNI_PLESC_1END_1TEXT_1get',['../plplotjavacJAVA__wrap_8c.html#a44b2370a838be16d65260ef7dbaeec50',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fplesc_5f1expose_5f1get',['Java_plplot_core_plplotjavacJNI_PLESC_1EXPOSE_1get',['../plplotjavacJAVA__wrap_8c.html#adfa07b111186b5c7e00fb2d3f849b41d',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fplesc_5f1fill_5f1get',['Java_plplot_core_plplotjavacJNI_PLESC_1FILL_1get',['../plplotjavacJAVA__wrap_8c.html#ae8c08eeb1f38f758ce11a4c6d3c02cde',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fplesc_5f1fixaspect_5f1get',['Java_plplot_core_plplotjavacJNI_PLESC_1FIXASPECT_1get',['../plplotjavacJAVA__wrap_8c.html#ab080435c71b65d72dbc27fff22d67735',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fplesc_5f1flush_5f1get',['Java_plplot_core_plplotjavacJNI_PLESC_1FLUSH_1get',['../plplotjavacJAVA__wrap_8c.html#a24d39a359ee8050c170a48814dfd2f9b',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fplesc_5f1flush_5f1remaining_5f1buffer_5f1get',['Java_plplot_core_plplotjavacJNI_PLESC_1FLUSH_1REMAINING_1BUFFER_1get',['../plplotjavacJAVA__wrap_8c.html#a52fd705c9766547c8617c6df4ebcfffe',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fplesc_5f1getbackend_5f1get',['Java_plplot_core_plplotjavacJNI_PLESC_1GETBACKEND_1get',['../plplotjavacJAVA__wrap_8c.html#af85d39b5f313f282bd4af65ea3fdbbd7',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fplesc_5f1getc_5f1get',['Java_plplot_core_plplotjavacJNI_PLESC_1GETC_1get',['../plplotjavacJAVA__wrap_8c.html#aff3bde1c6d631def66a5ccec185fecf4',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fplesc_5f1gradient_5f1get',['Java_plplot_core_plplotjavacJNI_PLESC_1GRADIENT_1get',['../plplotjavacJAVA__wrap_8c.html#ae85dc845b5922da2b8259cb268f3e8c2',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fplesc_5f1graph_5f1get',['Java_plplot_core_plplotjavacJNI_PLESC_1GRAPH_1get',['../plplotjavacJAVA__wrap_8c.html#a0ae84c83c9e64eed69f572e7b3b8067b',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fplesc_5f1has_5f1text_5f1get',['Java_plplot_core_plplotjavacJNI_PLESC_1HAS_1TEXT_1get',['../plplotjavacJAVA__wrap_8c.html#ab36494ce8f917381e446fa5cf12388cc',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fplesc_5f1image_5f1get',['Java_plplot_core_plplotjavacJNI_PLESC_1IMAGE_1get',['../plplotjavacJAVA__wrap_8c.html#a14b2fdc4815084a8ccb05f499fa66b35',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fplesc_5f1imageops_5f1get',['Java_plplot_core_plplotjavacJNI_PLESC_1IMAGEOPS_1get',['../plplotjavacJAVA__wrap_8c.html#a36449dbb6e0db65fc65fb67430df54b1',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fplesc_5f1import_5f1buffer_5f1get',['Java_plplot_core_plplotjavacJNI_PLESC_1IMPORT_1BUFFER_1get',['../plplotjavacJAVA__wrap_8c.html#a1a3442ec0d744a4e3a5871a084f6159f',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fplesc_5f1modeget_5f1get',['Java_plplot_core_plplotjavacJNI_PLESC_1MODEGET_1get',['../plplotjavacJAVA__wrap_8c.html#a4cc7abf65fbf5a25b59bfd7bf4d187a1',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fplesc_5f1modeset_5f1get',['Java_plplot_core_plplotjavacJNI_PLESC_1MODESET_1get',['../plplotjavacJAVA__wrap_8c.html#a096d65477297e0cd06c2219dd17e76cf',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fplesc_5f1pl2devcol_5f1get',['Java_plplot_core_plplotjavacJNI_PLESC_1PL2DEVCOL_1get',['../plplotjavacJAVA__wrap_8c.html#ae8603cc51a4dabf89d42e62c51265b64',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fplesc_5f1redraw_5f1get',['Java_plplot_core_plplotjavacJNI_PLESC_1REDRAW_1get',['../plplotjavacJAVA__wrap_8c.html#a509470fbd750e57e7abef7d013cf3093',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fplesc_5f1resize_5f1get',['Java_plplot_core_plplotjavacJNI_PLESC_1RESIZE_1get',['../plplotjavacJAVA__wrap_8c.html#a0b3b987a2c00c7e93b9997b3460ae854',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fplesc_5f1set_5f1compression_5f1get',['Java_plplot_core_plplotjavacJNI_PLESC_1SET_1COMPRESSION_1get',['../plplotjavacJAVA__wrap_8c.html#ae5a587cdadc48c6a5217dee20f8ef52e',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fplesc_5f1set_5f1lpb_5f1get',['Java_plplot_core_plplotjavacJNI_PLESC_1SET_1LPB_1get',['../plplotjavacJAVA__wrap_8c.html#a05cda972541b400f375bca59aba05004',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fplesc_5f1set_5f1rgb_5f1get',['Java_plplot_core_plplotjavacJNI_PLESC_1SET_1RGB_1get',['../plplotjavacJAVA__wrap_8c.html#a9aa0bd645a0eaaf0a1f8037e815803e8',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fplesc_5f1setbgfg_5f1get',['Java_plplot_core_plplotjavacJNI_PLESC_1SETBGFG_1get',['../plplotjavacJAVA__wrap_8c.html#aab8540d36af0285531e8e7dba6348430',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fplesc_5f1start_5f1rasterize_5f1get',['Java_plplot_core_plplotjavacJNI_PLESC_1START_1RASTERIZE_1get',['../plplotjavacJAVA__wrap_8c.html#a1ff14bd4bc9ea40c22c016ff81e8c124',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fplesc_5f1swin_5f1get',['Java_plplot_core_plplotjavacJNI_PLESC_1SWIN_1get',['../plplotjavacJAVA__wrap_8c.html#a295e96ee1838f42d8d569419ce36769d',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fplesc_5f1text_5f1char_5f1get',['Java_plplot_core_plplotjavacJNI_PLESC_1TEXT_1CHAR_1get',['../plplotjavacJAVA__wrap_8c.html#a07a8d864fee77004bb5e8d7df5ec6901',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fplesc_5f1text_5f1get',['Java_plplot_core_plplotjavacJNI_PLESC_1TEXT_1get',['../plplotjavacJAVA__wrap_8c.html#ad557161d6270dd25881edb1a034c10ae',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fplesc_5f1xormod_5f1get',['Java_plplot_core_plplotjavacJNI_PLESC_1XORMOD_1get',['../plplotjavacJAVA__wrap_8c.html#ae4be7a315a0a84b66784f1f16ff78e41',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fplfamadv',['Java_plplot_core_plplotjavacJNI_plfamadv',['../plplotjavacJAVA__wrap_8c.html#a5d15a52111af57d900a4d655210c1f60',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fplfill',['Java_plplot_core_plplotjavacJNI_plfill',['../plplotjavacJAVA__wrap_8c.html#a4d6522b68fcd5c109da1e30ea8ef48f0',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fplfill3',['Java_plplot_core_plplotjavacJNI_plfill3',['../plplotjavacJAVA__wrap_8c.html#a02ea95aa84647f0ec13d6c5678d991fe',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fplflush',['Java_plplot_core_plplotjavacJNI_plflush',['../plplotjavacJAVA__wrap_8c.html#ade09fa2818b1cd9cf9ea4e9c5b7c77fc',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fplfont',['Java_plplot_core_plplotjavacJNI_plfont',['../plplotjavacJAVA__wrap_8c.html#af9cdc0b80cb4d062178abab65b51c8d4',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fplfontld',['Java_plplot_core_plplotjavacJNI_plfontld',['../plplotjavacJAVA__wrap_8c.html#a08160447318a0e8f5c04db121528073e',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fplgchr',['Java_plplot_core_plplotjavacJNI_plgchr',['../plplotjavacJAVA__wrap_8c.html#a9dd1b823c7c77d76fd83fa828d12a341',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fplgcmap1_5f1range',['Java_plplot_core_plplotjavacJNI_plgcmap1_1range',['../plplotjavacJAVA__wrap_8c.html#ae0e3fd5cc34fbd6c32f96b4adc82e246',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fplgcol0',['Java_plplot_core_plplotjavacJNI_plgcol0',['../plplotjavacJAVA__wrap_8c.html#ab7cfc06a43efe7a489ae64218c7dc7ad',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fplgcol0a',['Java_plplot_core_plplotjavacJNI_plgcol0a',['../plplotjavacJAVA__wrap_8c.html#ac43dbbcf29ab1e3ce2d44108a09ce1e3',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fplgcolbg',['Java_plplot_core_plplotjavacJNI_plgcolbg',['../plplotjavacJAVA__wrap_8c.html#ac109d23653f610a07321f40e38fb551e',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fplgcolbga',['Java_plplot_core_plplotjavacJNI_plgcolbga',['../plplotjavacJAVA__wrap_8c.html#ac1facc4742fa2f672e4b0f9703fefcde',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fplgcompression',['Java_plplot_core_plplotjavacJNI_plgcompression',['../plplotjavacJAVA__wrap_8c.html#aaa900446520dee1d23934fb00eb7010f',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fplgdev',['Java_plplot_core_plplotjavacJNI_plgdev',['../plplotjavacJAVA__wrap_8c.html#afda854d8d45e1f720f116cbb280a7c3b',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fplgdidev',['Java_plplot_core_plplotjavacJNI_plgdidev',['../plplotjavacJAVA__wrap_8c.html#a4b5f997f0b7962276c1f14b43c5a3b42',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fplgdiori',['Java_plplot_core_plplotjavacJNI_plgdiori',['../plplotjavacJAVA__wrap_8c.html#a1f2fe1aff82602ed96aba0586dcbbbde',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fplgdiplt',['Java_plplot_core_plplotjavacJNI_plgdiplt',['../plplotjavacJAVA__wrap_8c.html#afd3eb1e81d7b7ecb542f2c3153ea7d19',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fplgetcursor',['Java_plplot_core_plplotjavacJNI_plGetCursor',['../plplotjavacJAVA__wrap_8c.html#a6815989493121dd2046bc1a68b63bd1a',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fplgfam',['Java_plplot_core_plplotjavacJNI_plgfam',['../plplotjavacJAVA__wrap_8c.html#a5baed4dd6da9b009d556cfac2a4c662b',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fplgfci',['Java_plplot_core_plplotjavacJNI_plgfci',['../plplotjavacJAVA__wrap_8c.html#a3a712d846ee410bb41c4acb0eb86e3d9',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fplgfnam',['Java_plplot_core_plplotjavacJNI_plgfnam',['../plplotjavacJAVA__wrap_8c.html#ac7145e241fb628f0c16ca947e9f750e3',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fplgfont',['Java_plplot_core_plplotjavacJNI_plgfont',['../plplotjavacJAVA__wrap_8c.html#af5ce0d15f9f6e0d12722d4e658fcb120',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fplglevel',['Java_plplot_core_plplotjavacJNI_plglevel',['../plplotjavacJAVA__wrap_8c.html#a8ea097d1cafd85ec6effe8bba652659b',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fplgpage',['Java_plplot_core_plplotjavacJNI_plgpage',['../plplotjavacJAVA__wrap_8c.html#a38c1c667e1cc884fffb768855f2e6fef',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fplgra',['Java_plplot_core_plplotjavacJNI_plgra',['../plplotjavacJAVA__wrap_8c.html#acc606192a9583fb56a49c281da46a131',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fplgradient',['Java_plplot_core_plplotjavacJNI_plgradient',['../plplotjavacJAVA__wrap_8c.html#a4af9f18de54a978e028af26f814da3e6',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fplgraphicsin_5f1button_5f1get',['Java_plplot_core_plplotjavacJNI_PLGraphicsIn_1button_1get',['../plplotjavacJAVA__wrap_8c.html#a9988bdda52a4aa5bca2e5272ba4bf8ec',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fplgraphicsin_5f1button_5f1set',['Java_plplot_core_plplotjavacJNI_PLGraphicsIn_1button_1set',['../plplotjavacJAVA__wrap_8c.html#a9e52090e300506370605203913ffbf60',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fplgraphicsin_5f1dx_5f1get',['Java_plplot_core_plplotjavacJNI_PLGraphicsIn_1dX_1get',['../plplotjavacJAVA__wrap_8c.html#a5188a42bddd27f0a737a577a2975661b',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fplgraphicsin_5f1dx_5f1set',['Java_plplot_core_plplotjavacJNI_PLGraphicsIn_1dX_1set',['../plplotjavacJAVA__wrap_8c.html#a6a212981a8c174bccd2216e1d5979dc8',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fplgraphicsin_5f1dy_5f1get',['Java_plplot_core_plplotjavacJNI_PLGraphicsIn_1dY_1get',['../plplotjavacJAVA__wrap_8c.html#ad5708d948c95431e045c08e87f7319b1',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fplgraphicsin_5f1dy_5f1set',['Java_plplot_core_plplotjavacJNI_PLGraphicsIn_1dY_1set',['../plplotjavacJAVA__wrap_8c.html#a97492eb5e3c6b2bb225aab0d50794587',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fplgraphicsin_5f1keysym_5f1get',['Java_plplot_core_plplotjavacJNI_PLGraphicsIn_1keysym_1get',['../plplotjavacJAVA__wrap_8c.html#a0e40c4a5ac8f3f472bdf56f0cb4fa8d0',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fplgraphicsin_5f1keysym_5f1set',['Java_plplot_core_plplotjavacJNI_PLGraphicsIn_1keysym_1set',['../plplotjavacJAVA__wrap_8c.html#a0c686259800b9345fdd9a23b29bf60e8',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fplgraphicsin_5f1px_5f1get',['Java_plplot_core_plplotjavacJNI_PLGraphicsIn_1pX_1get',['../plplotjavacJAVA__wrap_8c.html#aae2071d9cf23ce8e1d79ee7c0b7eb2c2',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fplgraphicsin_5f1px_5f1set',['Java_plplot_core_plplotjavacJNI_PLGraphicsIn_1pX_1set',['../plplotjavacJAVA__wrap_8c.html#abd5b347a77a929077a6963ea165ad187',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fplgraphicsin_5f1py_5f1get',['Java_plplot_core_plplotjavacJNI_PLGraphicsIn_1pY_1get',['../plplotjavacJAVA__wrap_8c.html#a21f1b4992cb32385ea24efb416b22fe9',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fplgraphicsin_5f1py_5f1set',['Java_plplot_core_plplotjavacJNI_PLGraphicsIn_1pY_1set',['../plplotjavacJAVA__wrap_8c.html#a53d8459ab4c1e70ca4c620fd01154ce3',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fplgraphicsin_5f1state_5f1get',['Java_plplot_core_plplotjavacJNI_PLGraphicsIn_1state_1get',['../plplotjavacJAVA__wrap_8c.html#aa214f3d0eb15ac86e6781aa63c5f639f',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fplgraphicsin_5f1state_5f1set',['Java_plplot_core_plplotjavacJNI_PLGraphicsIn_1state_1set',['../plplotjavacJAVA__wrap_8c.html#a199298750010a318306b3e9d9efe85eb',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fplgraphicsin_5f1string_5f1get',['Java_plplot_core_plplotjavacJNI_PLGraphicsIn_1string_1get',['../plplotjavacJAVA__wrap_8c.html#ad8c7484ebbc08a3ab527001e58f060dd',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fplgraphicsin_5f1string_5f1set',['Java_plplot_core_plplotjavacJNI_PLGraphicsIn_1string_1set',['../plplotjavacJAVA__wrap_8c.html#a8af6fb1611f86d8077ccd3c9d6ed2471',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fplgraphicsin_5f1subwindow_5f1get',['Java_plplot_core_plplotjavacJNI_PLGraphicsIn_1subwindow_1get',['../plplotjavacJAVA__wrap_8c.html#ae8be57d48a90118bca812e8f8d104877',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fplgraphicsin_5f1subwindow_5f1set',['Java_plplot_core_plplotjavacJNI_PLGraphicsIn_1subwindow_1set',['../plplotjavacJAVA__wrap_8c.html#adcc571e0fc0017fff6a19d431f1fa055',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fplgraphicsin_5f1type_5f1get',['Java_plplot_core_plplotjavacJNI_PLGraphicsIn_1type_1get',['../plplotjavacJAVA__wrap_8c.html#a29de497ee6adbac5f01482c586a18feb',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fplgraphicsin_5f1type_5f1set',['Java_plplot_core_plplotjavacJNI_PLGraphicsIn_1type_1set',['../plplotjavacJAVA__wrap_8c.html#a392617a1f48bb651dab972100cc26b76',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fplgraphicsin_5f1wx_5f1get',['Java_plplot_core_plplotjavacJNI_PLGraphicsIn_1wX_1get',['../plplotjavacJAVA__wrap_8c.html#a743790634c3875bed8eb2415fc596e9f',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fplgraphicsin_5f1wx_5f1set',['Java_plplot_core_plplotjavacJNI_PLGraphicsIn_1wX_1set',['../plplotjavacJAVA__wrap_8c.html#ac56d143c7ce1f3a135749ff31ebb887f',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fplgraphicsin_5f1wy_5f1get',['Java_plplot_core_plplotjavacJNI_PLGraphicsIn_1wY_1get',['../plplotjavacJAVA__wrap_8c.html#aa8d6be5b029f09f5e53afc29662a1ce7',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fplgraphicsin_5f1wy_5f1set',['Java_plplot_core_plplotjavacJNI_PLGraphicsIn_1wY_1set',['../plplotjavacJAVA__wrap_8c.html#aa23d17275464e06981057c8efcb89c90',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fplgriddata',['Java_plplot_core_plplotjavacJNI_plgriddata',['../plplotjavacJAVA__wrap_8c.html#ac45e203f0e0eeae84beecb79c3cc3c12',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fplgspa',['Java_plplot_core_plplotjavacJNI_plgspa',['../plplotjavacJAVA__wrap_8c.html#a72d91346312962fda4e5fd46362d8744',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fplgstrm',['Java_plplot_core_plplotjavacJNI_plgstrm',['../plplotjavacJAVA__wrap_8c.html#a7445f046409aa69d37c1052de519e69e',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fplgver',['Java_plplot_core_plplotjavacJNI_plgver',['../plplotjavacJAVA__wrap_8c.html#ae980c845e24be96dd4f7d939a82205ae',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fplgvpd',['Java_plplot_core_plplotjavacJNI_plgvpd',['../plplotjavacJAVA__wrap_8c.html#a4f7e5d336a9802c2cd7f8baaf889813a',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fplgvpw',['Java_plplot_core_plplotjavacJNI_plgvpw',['../plplotjavacJAVA__wrap_8c.html#ae26d119e12b228d055fed616eaaa961d',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fplgxax',['Java_plplot_core_plplotjavacJNI_plgxax',['../plplotjavacJAVA__wrap_8c.html#ae4fcc3a4966a72d16eec30a01c0289c0',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fplgyax',['Java_plplot_core_plplotjavacJNI_plgyax',['../plplotjavacJAVA__wrap_8c.html#aca00ba32d27f36feb62bc028a1ba6192',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fplgzax',['Java_plplot_core_plplotjavacJNI_plgzax',['../plplotjavacJAVA__wrap_8c.html#adb3ee67044e4c528bee2848f2223c43e',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fplhist',['Java_plplot_core_plplotjavacJNI_plhist',['../plplotjavacJAVA__wrap_8c.html#af01ccf774c089dbf54616d08b7edf326',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fplhlsrgb',['Java_plplot_core_plplotjavacJNI_plhlsrgb',['../plplotjavacJAVA__wrap_8c.html#ab8e50d10aad198671be18f5801b6e7cb',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fplimage',['Java_plplot_core_plplotjavacJNI_plimage',['../plplotjavacJAVA__wrap_8c.html#acb0a75c80ffdaebcc75551f4b596a633',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fplimagefr',['Java_plplot_core_plplotjavacJNI_plimagefr',['../plplotjavacJAVA__wrap_8c.html#a145fa2ac15670a6c3d982fa7af95c568',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fplinit',['Java_plplot_core_plplotjavacJNI_plinit',['../plplotjavacJAVA__wrap_8c.html#a69e9e7083a1122604384a269911c2b28',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fpljoin',['Java_plplot_core_plplotjavacJNI_pljoin',['../plplotjavacJAVA__wrap_8c.html#a282b7a5ce0df2c09372c378929135a58',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fpllab',['Java_plplot_core_plplotjavacJNI_pllab',['../plplotjavacJAVA__wrap_8c.html#ab8226287c6dbefb32d77bf63498bdd24',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fpllegend',['Java_plplot_core_plplotjavacJNI_pllegend',['../plplotjavacJAVA__wrap_8c.html#accdf73b6cba543b45b7f8fe3a1b67b58',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fpllightsource',['Java_plplot_core_plplotjavacJNI_pllightsource',['../plplotjavacJAVA__wrap_8c.html#afd3952b33d8d45e7757ba4efb546856a',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fplline',['Java_plplot_core_plplotjavacJNI_plline',['../plplotjavacJAVA__wrap_8c.html#a9e038a832732c02d303fd265871596b1',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fplline3',['Java_plplot_core_plplotjavacJNI_plline3',['../plplotjavacJAVA__wrap_8c.html#aef6dd8db2de4ec2717b9c0261473426e',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fpllsty',['Java_plplot_core_plplotjavacJNI_pllsty',['../plplotjavacJAVA__wrap_8c.html#a2ab116317ee6bfad7811215b82d735d3',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fplmap',['Java_plplot_core_plplotjavacJNI_plmap',['../plplotjavacJAVA__wrap_8c.html#a5a382f9a231f093ff8c0b81a4e9031b8',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fplmapfill',['Java_plplot_core_plplotjavacJNI_plmapfill',['../plplotjavacJAVA__wrap_8c.html#a960648930da60a3ceb2c5ea187d02ced',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fplmapline',['Java_plplot_core_plplotjavacJNI_plmapline',['../plplotjavacJAVA__wrap_8c.html#a1b484c279f107edb48d073818f6b9d42',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fplmapstring',['Java_plplot_core_plplotjavacJNI_plmapstring',['../plplotjavacJAVA__wrap_8c.html#a22b680a560a5ae5385092255e35e6aca',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fplmaptex',['Java_plplot_core_plplotjavacJNI_plmaptex',['../plplotjavacJAVA__wrap_8c.html#afd3411e9d8eb93a413f913539a4f18b2',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fplmeridians',['Java_plplot_core_plplotjavacJNI_plmeridians',['../plplotjavacJAVA__wrap_8c.html#ae06f6b61c1d928bd8291fb80a48c086e',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fplmesh',['Java_plplot_core_plplotjavacJNI_plmesh',['../plplotjavacJAVA__wrap_8c.html#a22461988e3976a9aec474b201bb727c3',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fplmeshc',['Java_plplot_core_plplotjavacJNI_plmeshc',['../plplotjavacJAVA__wrap_8c.html#a08e0e04b38cd041ee6c0fc2be9083185',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fplminmax2dgrid',['Java_plplot_core_plplotjavacJNI_plMinMax2dGrid',['../plplotjavacJAVA__wrap_8c.html#aef81a5965b339968a2cb362479ea7395',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fplmkstrm',['Java_plplot_core_plplotjavacJNI_plmkstrm',['../plplotjavacJAVA__wrap_8c.html#a04c8bea64b35e1e5a9c25cb0ebd39c83',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fplmtex',['Java_plplot_core_plplotjavacJNI_plmtex',['../plplotjavacJAVA__wrap_8c.html#a6fdba6deb9c7e794d8205f4e0215c5a8',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fplmtex3',['Java_plplot_core_plplotjavacJNI_plmtex3',['../plplotjavacJAVA__wrap_8c.html#aa3e0bf3ab13637a5e1c6a24512881a80',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fploptusage',['Java_plplot_core_plplotjavacJNI_plOptUsage',['../plplotjavacJAVA__wrap_8c.html#adaebb9166d5548d11a74be1daa3c88a4',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fplot3d',['Java_plplot_core_plplotjavacJNI_plot3d',['../plplotjavacJAVA__wrap_8c.html#a9a4b7456999ead150053e92f0820530e',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fplot3dc',['Java_plplot_core_plplotjavacJNI_plot3dc',['../plplotjavacJAVA__wrap_8c.html#ad9af7741e25e302b7bed70ac8c9a07ab',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fplot3dcl',['Java_plplot_core_plplotjavacJNI_plot3dcl',['../plplotjavacJAVA__wrap_8c.html#a04d916952c4c0d72ffe329bbb938fc60',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fplparseopts',['Java_plplot_core_plplotjavacJNI_plparseopts',['../plplotjavacJAVA__wrap_8c.html#a7980aedaa3d1d1e026fab0e90af2c2f0',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fplpat',['Java_plplot_core_plplotjavacJNI_plpat',['../plplotjavacJAVA__wrap_8c.html#a1ab9aae43d011b68e7a65d228e7af5c9',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fplpath',['Java_plplot_core_plplotjavacJNI_plpath',['../plplotjavacJAVA__wrap_8c.html#a773aa8c992af9131687d51d37a4edfd3',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fplpoin',['Java_plplot_core_plplotjavacJNI_plpoin',['../plplotjavacJAVA__wrap_8c.html#a834a8440a5bcebc61cf7ed3ae82393ce',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fplpoin3',['Java_plplot_core_plplotjavacJNI_plpoin3',['../plplotjavacJAVA__wrap_8c.html#a107ad279992d2dcae287248e3b99fe08',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fplpoly3',['Java_plplot_core_plplotjavacJNI_plpoly3',['../plplotjavacJAVA__wrap_8c.html#af6b9a118ade3ec92468f4aee4788bc50',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fplprec',['Java_plplot_core_plplotjavacJNI_plprec',['../plplotjavacJAVA__wrap_8c.html#a2e77f2277dea4a32e38d05cf1dd100fb',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fplpsty',['Java_plplot_core_plplotjavacJNI_plpsty',['../plplotjavacJAVA__wrap_8c.html#a77fb646d932ab29bec680099b3276f9e',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fplptex',['Java_plplot_core_plplotjavacJNI_plptex',['../plplotjavacJAVA__wrap_8c.html#aca51f6e60afcf7ed1702ce6226b49d44',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fplptex3',['Java_plplot_core_plplotjavacJNI_plptex3',['../plplotjavacJAVA__wrap_8c.html#a9facc060c446b37ba161db116a708759',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fplrandd',['Java_plplot_core_plplotjavacJNI_plrandd',['../plplotjavacJAVA__wrap_8c.html#ad22b293297f4bf8d2710aa227f2475c8',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fplreplot',['Java_plplot_core_plplotjavacJNI_plreplot',['../plplotjavacJAVA__wrap_8c.html#a997d74a395bd3d88a8112bb2fc2bd2b5',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fplresetopts',['Java_plplot_core_plplotjavacJNI_plResetOpts',['../plplotjavacJAVA__wrap_8c.html#a47e61c2e36f1470cc0ff84ff257458c0',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fplrgbhls',['Java_plplot_core_plplotjavacJNI_plrgbhls',['../plplotjavacJAVA__wrap_8c.html#a3f7f6e1bf6258c42f439b0134bc0dd19',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fplschr',['Java_plplot_core_plplotjavacJNI_plschr',['../plplotjavacJAVA__wrap_8c.html#a7105574bf6d99f547cf6379164dcc4a6',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fplscmap0',['Java_plplot_core_plplotjavacJNI_plscmap0',['../plplotjavacJAVA__wrap_8c.html#ae0024b0cd834d097841122f4e0001c26',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fplscmap0a',['Java_plplot_core_plplotjavacJNI_plscmap0a',['../plplotjavacJAVA__wrap_8c.html#a07be45a6f063f9bf2ddc2dd61ea21973',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fplscmap0n',['Java_plplot_core_plplotjavacJNI_plscmap0n',['../plplotjavacJAVA__wrap_8c.html#afec75f0af6b398960362e152c7a26189',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fplscmap1',['Java_plplot_core_plplotjavacJNI_plscmap1',['../plplotjavacJAVA__wrap_8c.html#a08823e3febfabd30977bcbb83ef0de63',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fplscmap1_5f1range',['Java_plplot_core_plplotjavacJNI_plscmap1_1range',['../plplotjavacJAVA__wrap_8c.html#a7f8b6d55ac89edb5ea9bab75a66cdc4e',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fplscmap1a',['Java_plplot_core_plplotjavacJNI_plscmap1a',['../plplotjavacJAVA__wrap_8c.html#a019ded59f3a1f1fbab8e82c55b13d98d',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fplscmap1l',['Java_plplot_core_plplotjavacJNI_plscmap1l',['../plplotjavacJAVA__wrap_8c.html#a39f07268f5393037fe60839912d04b4e',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fplscmap1la',['Java_plplot_core_plplotjavacJNI_plscmap1la',['../plplotjavacJAVA__wrap_8c.html#a5358d845620d459fe82a11db174fa488',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fplscmap1n',['Java_plplot_core_plplotjavacJNI_plscmap1n',['../plplotjavacJAVA__wrap_8c.html#a8484fb1ead4f746652370fa063026c9c',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fplscol0',['Java_plplot_core_plplotjavacJNI_plscol0',['../plplotjavacJAVA__wrap_8c.html#ae8a5eaba6dcc06d2bfdad241e7b020ee',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fplscol0a',['Java_plplot_core_plplotjavacJNI_plscol0a',['../plplotjavacJAVA__wrap_8c.html#abea7e2e867d998ee8e1e58ead2f24c61',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fplscolbg',['Java_plplot_core_plplotjavacJNI_plscolbg',['../plplotjavacJAVA__wrap_8c.html#a0eaacb6f60ca79f624e3ab79dde97c36',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fplscolbga',['Java_plplot_core_plplotjavacJNI_plscolbga',['../plplotjavacJAVA__wrap_8c.html#a15a176546e88182c88b08a39dcd7a57c',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fplscolor',['Java_plplot_core_plplotjavacJNI_plscolor',['../plplotjavacJAVA__wrap_8c.html#a51f60e8ea4dd9314ebbbd6cb4e7b931b',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fplscompression',['Java_plplot_core_plplotjavacJNI_plscompression',['../plplotjavacJAVA__wrap_8c.html#af764ad17d4b1cd2a46dd1213160c495a',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fplsdev',['Java_plplot_core_plplotjavacJNI_plsdev',['../plplotjavacJAVA__wrap_8c.html#ae313d1badb2a60a9e697b5e7393a3bfd',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fplsdidev',['Java_plplot_core_plplotjavacJNI_plsdidev',['../plplotjavacJAVA__wrap_8c.html#ac01eff2af207f1e4fb205ad62c65b854',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fplsdimap',['Java_plplot_core_plplotjavacJNI_plsdimap',['../plplotjavacJAVA__wrap_8c.html#aba186447a593315aa68bf347258def81',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fplsdiori',['Java_plplot_core_plplotjavacJNI_plsdiori',['../plplotjavacJAVA__wrap_8c.html#ad9f216e3507f66ee2fb692f64da56291',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fplsdiplt',['Java_plplot_core_plplotjavacJNI_plsdiplt',['../plplotjavacJAVA__wrap_8c.html#a304eaeb251f23d41d16cdf795cfff4a1',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fplsdiplz',['Java_plplot_core_plplotjavacJNI_plsdiplz',['../plplotjavacJAVA__wrap_8c.html#a31ecd95042b3c51f764ce9e7ecdb8292',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fplseed',['Java_plplot_core_plplotjavacJNI_plseed',['../plplotjavacJAVA__wrap_8c.html#a405dcf4e82e4137faeb2a269fef89f32',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fplsesc',['Java_plplot_core_plplotjavacJNI_plsesc',['../plplotjavacJAVA__wrap_8c.html#af5016cad05026569dad2f9c1e66b0848',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fplsetopt',['Java_plplot_core_plplotjavacJNI_plsetopt',['../plplotjavacJAVA__wrap_8c.html#a2bdd8ff98eb7459a1c1411fabe286570',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fplsetusage',['Java_plplot_core_plplotjavacJNI_plSetUsage',['../plplotjavacJAVA__wrap_8c.html#a5b05e373f65b03aa505c6b1c715262b6',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fplsfam',['Java_plplot_core_plplotjavacJNI_plsfam',['../plplotjavacJAVA__wrap_8c.html#a0d3fdd1fa530130c84d5899de2ec8b01',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fplsfci',['Java_plplot_core_plplotjavacJNI_plsfci',['../plplotjavacJAVA__wrap_8c.html#aef3da56a507e6427534c991130925dfd',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fplsfnam',['Java_plplot_core_plplotjavacJNI_plsfnam',['../plplotjavacJAVA__wrap_8c.html#a2e1efa5f945dcf84f88af9d9b3b4d0c0',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fplsfont',['Java_plplot_core_plplotjavacJNI_plsfont',['../plplotjavacJAVA__wrap_8c.html#ab8f523374d445f837e51a5161dd36789',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fplshade',['Java_plplot_core_plplotjavacJNI_plshade',['../plplotjavacJAVA__wrap_8c.html#a9915b47ef8a30166e51d5f054d3db2a4',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fplshades',['Java_plplot_core_plplotjavacJNI_plshades',['../plplotjavacJAVA__wrap_8c.html#a5e3190427cf9012101951e0ca3c9be41',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fplslabelfunc',['Java_plplot_core_plplotjavacJNI_plslabelfunc',['../plplotjavacJAVA__wrap_8c.html#a0da464cb30009875c3b3415260e94e58',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fplsmaj',['Java_plplot_core_plplotjavacJNI_plsmaj',['../plplotjavacJAVA__wrap_8c.html#a9269606e75bca480cbd7d32db19c3d8f',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fplsmin',['Java_plplot_core_plplotjavacJNI_plsmin',['../plplotjavacJAVA__wrap_8c.html#a9c8f2a133c8947b49e290be56f749188',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fplsori',['Java_plplot_core_plplotjavacJNI_plsori',['../plplotjavacJAVA__wrap_8c.html#ad1af8c87a6492c37d59e22720b343313',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fplspage',['Java_plplot_core_plplotjavacJNI_plspage',['../plplotjavacJAVA__wrap_8c.html#a9dca5fee89a83a92a561f662c17649e8',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fplspal0',['Java_plplot_core_plplotjavacJNI_plspal0',['../plplotjavacJAVA__wrap_8c.html#aef3103d0eafbda2c28655c328ba81ef8',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fplspal1',['Java_plplot_core_plplotjavacJNI_plspal1',['../plplotjavacJAVA__wrap_8c.html#aa414e1c205430f363315b44512a1450c',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fplspause',['Java_plplot_core_plplotjavacJNI_plspause',['../plplotjavacJAVA__wrap_8c.html#aa5f4cb55eafe73c8ac7ee77010c6f636',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fplsstrm',['Java_plplot_core_plplotjavacJNI_plsstrm',['../plplotjavacJAVA__wrap_8c.html#a573fbfcf346ea6427d097497822242a3',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fplssub',['Java_plplot_core_plplotjavacJNI_plssub',['../plplotjavacJAVA__wrap_8c.html#a5fa2e1d8fcae62bf821d2470285c2453',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fplssym',['Java_plplot_core_plplotjavacJNI_plssym',['../plplotjavacJAVA__wrap_8c.html#aab958f5ff66ef557985a81115f8d5122',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fplstar',['Java_plplot_core_plplotjavacJNI_plstar',['../plplotjavacJAVA__wrap_8c.html#af0a6df2c720dfdfa467d9055048fc545',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fplstart',['Java_plplot_core_plplotjavacJNI_plstart',['../plplotjavacJAVA__wrap_8c.html#a5e913fc09dd34cb09dda1f04b71b2fe8',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fplstransform',['Java_plplot_core_plplotjavacJNI_plstransform',['../plplotjavacJAVA__wrap_8c.html#a466a07448dcacb71e4d1f1b1d238e5c2',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fplstring',['Java_plplot_core_plplotjavacJNI_plstring',['../plplotjavacJAVA__wrap_8c.html#a1c21e87b8d50c8501db2faeaa9998f11',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fplstring3',['Java_plplot_core_plplotjavacJNI_plstring3',['../plplotjavacJAVA__wrap_8c.html#a9ea0d0e43bf7df63567e24f9f5e209e5',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fplstripa',['Java_plplot_core_plplotjavacJNI_plstripa',['../plplotjavacJAVA__wrap_8c.html#acb74641b58e25244a3d1a6428f01ec62',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fplstripc',['Java_plplot_core_plplotjavacJNI_plstripc',['../plplotjavacJAVA__wrap_8c.html#a3a720c219b0349d90f165f86c3631731',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fplstripd',['Java_plplot_core_plplotjavacJNI_plstripd',['../plplotjavacJAVA__wrap_8c.html#a9e556d7ffa04a12b8535e8a3e870c2d0',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fplstyl',['Java_plplot_core_plplotjavacJNI_plstyl',['../plplotjavacJAVA__wrap_8c.html#a1feb9b908d322df417b7d432986d0798',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fplsurf3d',['Java_plplot_core_plplotjavacJNI_plsurf3d',['../plplotjavacJAVA__wrap_8c.html#a2dc5dd5f731691e2a084b2682f9edb9c',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fplsurf3dl',['Java_plplot_core_plplotjavacJNI_plsurf3dl',['../plplotjavacJAVA__wrap_8c.html#ab55c85efe04836947357585143d7aee4',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fplsvect',['Java_plplot_core_plplotjavacJNI_plsvect',['../plplotjavacJAVA__wrap_8c.html#a4a437aba5165aea7bf737ab9a8dd6d6b',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fplsvpa',['Java_plplot_core_plplotjavacJNI_plsvpa',['../plplotjavacJAVA__wrap_8c.html#ab0550aab459ab67ed37324176e1e81b7',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fplswin_5f1device_5f1get',['Java_plplot_core_plplotjavacJNI_PLSWIN_1DEVICE_1get',['../plplotjavacJAVA__wrap_8c.html#a73c8c2267e278779ac891d56762e1ebf',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fplswin_5f1world_5f1get',['Java_plplot_core_plplotjavacJNI_PLSWIN_1WORLD_1get',['../plplotjavacJAVA__wrap_8c.html#ace33bc1633b36a8ded9c7a300bb6cf97',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fplsxax',['Java_plplot_core_plplotjavacJNI_plsxax',['../plplotjavacJAVA__wrap_8c.html#af617a7d0d5e9a1b9b51105d6a67b5570',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fplsyax',['Java_plplot_core_plplotjavacJNI_plsyax',['../plplotjavacJAVA__wrap_8c.html#aa198843906e72a0a1651774341da1a68',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fplsym',['Java_plplot_core_plplotjavacJNI_plsym',['../plplotjavacJAVA__wrap_8c.html#a5c905b083639c35b7485f9937723e282',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fplszax',['Java_plplot_core_plplotjavacJNI_plszax',['../plplotjavacJAVA__wrap_8c.html#a99c8be5f9488b625e44b6336101d3167',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fpltext',['Java_plplot_core_plplotjavacJNI_pltext',['../plplotjavacJAVA__wrap_8c.html#a2701c8d8779606f327d70703afb1464d',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fpltext_5f1backchar_5f1get',['Java_plplot_core_plplotjavacJNI_PLTEXT_1BACKCHAR_1get',['../plplotjavacJAVA__wrap_8c.html#a1fc5c37ba522e7347781f397ea2d0eba',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fpltext_5f1fontchange_5f1get',['Java_plplot_core_plplotjavacJNI_PLTEXT_1FONTCHANGE_1get',['../plplotjavacJAVA__wrap_8c.html#a012bfea10a5cc0fdf932db021dd2698f',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fpltext_5f1overline_5f1get',['Java_plplot_core_plplotjavacJNI_PLTEXT_1OVERLINE_1get',['../plplotjavacJAVA__wrap_8c.html#a891368a7b4b090619f2fe531c1be5522',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fpltext_5f1subscript_5f1get',['Java_plplot_core_plplotjavacJNI_PLTEXT_1SUBSCRIPT_1get',['../plplotjavacJAVA__wrap_8c.html#a0be3b21d14f19edf872fe3f62f298d37',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fpltext_5f1superscript_5f1get',['Java_plplot_core_plplotjavacJNI_PLTEXT_1SUPERSCRIPT_1get',['../plplotjavacJAVA__wrap_8c.html#a1c1c98e9ac979c19820013bf246a4969',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fpltext_5f1underline_5f1get',['Java_plplot_core_plplotjavacJNI_PLTEXT_1UNDERLINE_1get',['../plplotjavacJAVA__wrap_8c.html#af68532f80e4fecbf6ceecbac513a6aad',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fpltimefmt',['Java_plplot_core_plplotjavacJNI_pltimefmt',['../plplotjavacJAVA__wrap_8c.html#aa271448ad652d6db67d37203c962b086',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fplvasp',['Java_plplot_core_plplotjavacJNI_plvasp',['../plplotjavacJAVA__wrap_8c.html#a0f0f3ecca022357617e7e4a851074de3',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fplvect',['Java_plplot_core_plplotjavacJNI_plvect',['../plplotjavacJAVA__wrap_8c.html#a3eebd8f5a447f010af1ba583b99655c0',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fplvpas',['Java_plplot_core_plplotjavacJNI_plvpas',['../plplotjavacJAVA__wrap_8c.html#a3ac18f4fe9b0025c2a1b93ec78ef0cd4',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fplvpor',['Java_plplot_core_plplotjavacJNI_plvpor',['../plplotjavacJAVA__wrap_8c.html#a48cc48baf7e9d5a341c4fd8268819b76',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fplvsta',['Java_plplot_core_plplotjavacJNI_plvsta',['../plplotjavacJAVA__wrap_8c.html#aa2c86631075a89f58f21bfde945c545a',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fplw3d',['Java_plplot_core_plplotjavacJNI_plw3d',['../plplotjavacJAVA__wrap_8c.html#ab570444bd97efc6102c7595f19526dae',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fplwidth',['Java_plplot_core_plplotjavacJNI_plwidth',['../plplotjavacJAVA__wrap_8c.html#a5992a40216c22c599ee3c1f71fac7c3b',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fplwind',['Java_plplot_core_plplotjavacJNI_plwind',['../plplotjavacJAVA__wrap_8c.html#a61a640cea0971a16c0a12c48f5c36379',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fplxormod',['Java_plplot_core_plplotjavacJNI_plxormod',['../plplotjavacJAVA__wrap_8c.html#a13ffa7368db75f7f381db576cb875af2',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fsurf_5f1cont_5f1get',['Java_plplot_core_plplotjavacJNI_SURF_1CONT_1get',['../plplotjavacJAVA__wrap_8c.html#a320b2d94c05c16bef8f35241f19a9efb',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5ftop_5f1cont_5f1get',['Java_plplot_core_plplotjavacJNI_TOP_1CONT_1get',['../plplotjavacJAVA__wrap_8c.html#ab658f85b28aa5647040504d19acafa09',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fzerow2b_5f1get',['Java_plplot_core_plplotjavacJNI_ZEROW2B_1get',['../plplotjavacJAVA__wrap_8c.html#a4ebea97b3bdf7ced1444d488fab6a484',1,'plplotjavacJAVA_wrap.c']]],
  ['java_5fplplot_5fcore_5fplplotjavacjni_5fzerow2d_5f1get',['Java_plplot_core_plplotjavacJNI_ZEROW2D_1get',['../plplotjavacJAVA__wrap_8c.html#ad46aba95ecdbd73483914da8dd636580',1,'plplotjavacJAVA_wrap.c']]],
  ['jni_5fonload',['JNI_OnLoad',['../plplotjavacJAVA__wrap_8c.html#a4ff91b72859d8f0d77935907f3c78243',1,'plplotjavacJAVA_wrap.c']]],
  ['join',['join',['../classplstream.html#a197265e0119b7d0b3ed0a72caac1b29d',1,'plstream::join()'],['../classplplot_1_1core_1_1PLStream.html#a8c35fdc786e38f7f955ebebed6edfcb9',1,'plplot.core.PLStream.join()']]],
  ['jplfltarray',['jPLFLTArray',['../interfaceplplot_1_1core_1_1plplotjavacConstants.html#a92daefbe46769fd61eb907b6f9ab5932',1,'plplot::core::plplotjavacConstants']]],
  ['jplfltarray_5fget',['jPLFLTArray_get',['../classplplot_1_1core_1_1plplotjavacJNI.html#aab70c48039262d5b5f05effaa5024994',1,'plplot::core::plplotjavacJNI']]],
  ['jplfltbracket',['jPLFLTbracket',['../interfaceplplot_1_1core_1_1plplotjavacConstants.html#a14c6573f4a10348b94021ad53a787fc9',1,'plplot::core::plplotjavacConstants']]],
  ['jplfltbracket2',['jPLFLTbracket2',['../interfaceplplot_1_1core_1_1plplotjavacConstants.html#a541e25b949e81770d55f9f1eb93d0ba0',1,'plplot::core::plplotjavacConstants']]],
  ['jplfltbracket2_5fget',['jPLFLTbracket2_get',['../classplplot_1_1core_1_1plplotjavacJNI.html#a4f157be8ea97da0e4487aae04dd0cfb9',1,'plplot::core::plplotjavacJNI']]],
  ['jplfltbracket_5fget',['jPLFLTbracket_get',['../classplplot_1_1core_1_1plplotjavacJNI.html#a87f60ac379f8740729c7ca5e85d9e572',1,'plplot::core::plplotjavacJNI']]],
  ['just',['just',['../structEscText.html#a614a565c3a8f395dd0dd27e616252682',1,'EscText']]],
  ['jx',['jx',['../structPLStream.html#a679d1f6d61d384bbc6689c40aea9fb39',1,'PLStream']]],
  ['jy',['jy',['../structPLStream.html#a516918f5d44640cbbd0bcd4712305281',1,'PLStream']]]
];
